@@ -61,7 +61,11 @@ class AttackWEP(Attack):
 
                     Color.clear_line()
                     Color.p('\r{+} {O}waiting{W} for target to appear...')
-                    airodump_target = self.wait_for_target(airodump)
+                    try:
+                        airodump_target = self.wait_for_target(airodump)
+                    except Exception as e:
+                        Color.pl('\n{!} {R}Target timeout:{W} %s' % str(e))
+                        break
 
                     fakeauth_proc = None
                     if self.fake_auth():
@@ -95,7 +99,11 @@ class AttackWEP(Attack):
 
                     # Loop until attack completes.
                     while True:
-                        airodump_target = self.wait_for_target(airodump)
+                        try:
+                            airodump_target = self.wait_for_target(airodump)
+                        except Exception as e:
+                            Color.pl('\n{!} {R}Target timeout:{W} %s' % str(e))
+                            break
 
                         if client_mac is None and len(airodump_target.clients) > 0:
                             client_mac = airodump_target.clients[0].station
@@ -243,7 +251,18 @@ class AttackWEP(Attack):
                     self.success = False
                     return self.success
 
+            except (OSError, IOError) as e:
+                Color.pl('\r {!} {R}File System Error{W}: %s' % str(e))
+                continue
+            except subprocess.CalledProcessError as e:
+                Color.pl('\r {!} {R}WEP Tool Failed{W}: %s' % str(e))
+                continue
+            except ValueError as e:
+                Color.pl('\r {!} {R}Invalid WEP Configuration{W}: %s' % str(e))
+                continue
             except Exception as e:
+                # Log unexpected errors with full trace for WEP debugging
+                Color.pl('\r {!} {R}Unexpected WEP Error{W}: %s' % str(e))
                 Color.pexception(e)
                 continue
                 # End of big try-catch
@@ -353,4 +372,4 @@ if __name__ == '__main__':
     target = Target(fields)
     wep = AttackWEP(target)
     wep.run()
-    Configuration.exit_gracefully(0)
+    Configuration.exit_gracefully()
