@@ -3,7 +3,6 @@
 
 import os
 import re
-
 from .util.color import Color
 from .tools.macchanger import Macchanger
 
@@ -13,7 +12,7 @@ class Configuration(object):
 
     initialized = False  # Flag indicating config has been initialized
     verbose = 0
-    version = '2.7.0'
+    version = '2.8.1'
 
     all_bands = None
     attack_max = None
@@ -37,7 +36,7 @@ class Configuration(object):
     min_power = None
     no_deauth = None
     no_wps = None
-    no_nullpin = None
+    wps_no_nullpin = None
     num_deauths = None
     pmkid_timeout = None
     print_stack_traces = None
@@ -46,6 +45,9 @@ class Configuration(object):
     scan_time = None
     show_bssids = None
     show_cracked = None
+    show_ignored = None
+    update_db = None
+    db_filename = None
     show_manufacturers = None
     skip_crack = None
     target_bssid = None
@@ -54,6 +56,7 @@ class Configuration(object):
     temp_dir = None  # Temporary directory
     two_ghz = None
     use_bully = None
+    use_reaver = None
     use_eviltwin = None
     use_pmkid_only = None
     wep_attacks = None
@@ -147,7 +150,9 @@ class Configuration(object):
         cls.wep_keep_ivs = False  # Retain .ivs files across multiple attacks.
 
         # WPA variables
-        cls.wpa_filter = False  # Only attack WPA networks
+        cls.wpa_filter = False  # Only attack WPA/WPA2 networks
+        cls.wpa3_filter = False # Only attack WPA3 networks
+        cls.owe_filter = False # Only attack OWE networks
         cls.wpa_deauth_timeout = 15  # Wait time between deauths
         cls.wpa_attack_timeout = 300  # Wait time before failing
         cls.wpa_handshake_dir = 'hs'  # Dir to store handshakes
@@ -209,8 +214,11 @@ class Configuration(object):
 
         # Commands
         cls.show_cracked = False
+        cls.show_ignored = False
         cls.check_handshake = None
         cls.crack_handshake = False
+        cls.update_db = False
+        cls.db_filename = 'ieee-oui.txt'
 
         # A list to cache all checked commands (e.g. `which hashcat` will execute only once)
         cls.existing_commands = {}
@@ -257,11 +265,14 @@ class Configuration(object):
         # Commands
         if args.cracked:
             cls.show_cracked = True
+        if args.ignored:
+            cls.show_ignored = True
         if args.check_handshake:
             cls.check_handshake = args.check_handshake
         if args.crack_handshake:
             cls.crack_handshake = True
-
+        if args.update_db:
+            cls.update_db = True
     @classmethod
     def validate(cls):
         if cls.use_pmkid_only and cls.wps_only:
@@ -280,7 +291,7 @@ class Configuration(object):
             Color.pl('{+} {C}option:{W} using {G}random mac address{W} when scanning & attacking')
 
         if args.channel:
-            chn_arg_re = re.compile("^\d+((,\d+)|(-\d+,\d+))*(-\d+)?$")
+            chn_arg_re = re.compile(r"^\d+((,\d+)|(-\d+,\d+))*(-\d+)?$")
             if not chn_arg_re.match(args.channel):
                 raise ValueError("Invalid channel! The format must be 1,3-6,9")
 
@@ -356,10 +367,11 @@ class Configuration(object):
             Color.pl('{+} {C}option: {O}ignoring ESSID(s): {R}%s{W}' %
                      ', '.join(args.ignore_essids))
 
+        from .model.result import CrackResult
+        cls.ignore_cracked = CrackResult.load_ignored_bssids(args.ignore_cracked)
+
         if args.ignore_cracked:
-            from .model.result import CrackResult
-            if cracked_targets := CrackResult.load_all():
-                cls.ignore_cracked = [item['bssid'] for item in cracked_targets]
+            if cls.ignore_cracked:
                 Color.pl('{+} {C}option: {O}ignoring {R}%s{O} previously-cracked targets' % len(cls.ignore_cracked))
 
             else:
@@ -423,6 +435,12 @@ class Configuration(object):
         if args.wpa_filter:
             cls.wpa_filter = args.wpa_filter
 
+        if hasattr(args, 'wpa3_filter') and args.wpa3_filter:
+            cls.wpa3_filter = args.wpa3_filter
+
+        if hasattr(args, 'owe_filter') and args.owe_filter:
+            cls.owe_filter = args.owe_filter
+
         if args.wordlist:
             if not os.path.exists(args.wordlist):
                 cls.wordlist = None
@@ -479,6 +497,7 @@ class Configuration(object):
 
         elif args.wps_pixie:
             # WPS Pixie-Dust only
+            cls.no_wps = False  # Explicitly ensure WPS attacks are enabled
             cls.wps_pixie = True
             cls.wps_no_nullpin = True
             cls.wps_pin = False
@@ -486,6 +505,7 @@ class Configuration(object):
 
         elif args.wps_no_nullpin:
             # WPS NULL PIN only
+            cls.no_wps = False  # Explicitly ensure WPS attacks are enabled
             cls.wps_pixie = True
             cls.wps_no_nullpin = False
             cls.wps_pin = True
@@ -493,6 +513,7 @@ class Configuration(object):
 
         elif args.wps_no_pixie:
             # WPS PIN only
+            cls.no_wps = False  # Explicitly ensure WPS attacks are enabled
             cls.wps_pixie = False
             cls.wps_no_nullpin = True
             cls.wps_pin = True
@@ -553,16 +574,23 @@ class Configuration(object):
         cls.encryption_filter = []
         if cls.wep_filter:
             cls.encryption_filter.append('WEP')
-        if cls.wpa_filter:
-            cls.encryption_filter.append('WPA')
-        if cls.wps_filter:
+        if cls.wpa_filter: # WPA/WPA2
+            cls.encryption_filter.append('WPA') 
+        if cls.wpa3_filter:
+            cls.encryption_filter.append('WPA3')
+        if cls.owe_filter:
+            cls.encryption_filter.append('OWE')
+        if cls.wps_filter: # WPS can be on WPA/WPA2
             cls.encryption_filter.append('WPS')
 
-        if len(cls.encryption_filter) == 3:
-            Color.pl('{+} {C}option:{W} targeting {G}all encrypted networks{W}')
-        elif not cls.encryption_filter:
-            # Default to scan all types
-            cls.encryption_filter = ['WEP', 'WPA', 'WPS']
+        cls.encryption_filter = sorted(list(set(cls.encryption_filter))) # Remove duplicates and sort
+
+        if not cls.encryption_filter:
+            # Default to scan all known types if no specific filter is chosen
+            cls.encryption_filter = ['WEP', 'WPA', 'WPA3', 'OWE', 'WPS']
+            Color.pl('{+} {C}option:{W} targeting {G}all known encryption types{W} by default')
+        elif len(cls.encryption_filter) == 5 and 'WPS' in cls.encryption_filter and 'OWE' in cls.encryption_filter: # Approximation for "all"
+             Color.pl('{+} {C}option:{W} targeting {G}all specified encrypted networks{W}')
         else:
             Color.pl('{+} {C}option:{W} targeting {G}%s-encrypted{W} networks' % '/'.join(cls.encryption_filter))
 
@@ -624,12 +652,37 @@ class Configuration(object):
             return
         if os.path.exists(cls.temp_dir):
             for f in os.listdir(cls.temp_dir):
-                os.remove(cls.temp_dir + f)
-            os.rmdir(cls.temp_dir)
+                try:
+                    file_path = os.path.join(cls.temp_dir, f)
+                    os.remove(file_path)
+                except (OSError, IOError):
+                    pass  # Ignore errors during cleanup
+            try:
+                os.rmdir(cls.temp_dir)
+            except (OSError, IOError):
+                pass  # Ignore errors during cleanup
 
     @classmethod
-    def exit_gracefully(cls, code=0):
+    def cleanup_memory(cls):
+        """ Periodic memory cleanup during long operations """
+        # Clear command cache periodically
+        if hasattr(cls, 'existing_commands') and len(cls.existing_commands) > 100:
+            # Keep only the most recently used commands
+            cls.existing_commands = dict(list(cls.existing_commands.items())[-50:])
+
+        # Clean up processes and file descriptors
+        from .util.process import ProcessManager, Process
+        ProcessManager().cleanup_all()
+        Process.cleanup_zombies()
+
+        # Force garbage collection
+        import gc
+        gc.collect()
+
+    @classmethod
+    def exit_gracefully(cls):
         """ Deletes temp and exist with the given code """
+        code = 0
         cls.delete_temp()
         Macchanger.reset_if_changed()
         from .tools.airmon import Airmon
