@@ -4,8 +4,9 @@
 import time
 from ..config import Configuration
 
+
 class Attack(object):
-    '''Contains functionality common to all attacks.'''
+    """Contains functionality common to all attacks."""
 
     target_wait = min(60, Configuration.wpa_attack_timeout)
 
@@ -16,26 +17,20 @@ class Attack(object):
         raise Exception('Unimplemented method: run')
 
     def wait_for_target(self, airodump):
-        '''Waits for target to appear in airodump.'''
+        """Waits for target to appear in airodump."""
         start_time = time.time()
         targets = airodump.get_targets(apply_filter=False)
         while len(targets) == 0:
             # Wait for target to appear in airodump.
             if int(time.time() - start_time) > Attack.target_wait:
-                raise Exception('Target did not appear after %d seconds, stopping' % Attack.target_wait)
+                raise Exception(f'Target did not appear after {Attack.target_wait:d} seconds, target may be out of range or turned off')
             time.sleep(1)
             targets = airodump.get_targets()
             continue
 
-        # Ensure this target was seen by airodump
-        airodump_target = None
-        for t in targets:
-            if t.bssid == self.target.bssid:
-                airodump_target = t
-                break
+        airodump_target = next((t for t in targets if t.bssid == self.target.bssid), None)
 
         if airodump_target is None:
-            raise Exception(
-                'Could not find target (%s) in airodump' % self.target.bssid)
+            raise Exception(f'Could not find target ({self.target.bssid}) in airodump')
 
         return airodump_target
