@@ -24,8 +24,7 @@ class Iw(Dependency):
         import re
 
         ireg = re.compile(r"\s+Interface\s[a-zA-Z\d]+")
-        mreg = re.compile(r"\s+type\s[a-zA-z]+")
-        ires = None
+        mreg = re.compile(r"\s+type\s[a-zA-Z]+")
 
         interfaces = set()
         iface = ''
@@ -36,7 +35,6 @@ class Iw(Dependency):
                 if ires := ireg.search(line):
                     interfaces.add(ires.group().split("Interface")[-1])
         else:
-            mres = None
             for line in out.split('\n'):
                 ires = ireg.search(line)
                 if mres := mreg.search(line):
@@ -46,3 +44,9 @@ class Iw(Dependency):
                     iface = ires.group().split("Interface")[-1][1:]
 
         return list(interfaces)
+
+    @classmethod
+    def is_monitor(cls, iface):
+        """Check if the given interface is in monitor mode"""
+        monitor_interfaces = cls.get_interfaces(mode='monitor')
+        return iface in monitor_interfaces
