@@ -5,7 +5,7 @@ import sys
 
 
 class Color(object):
-    ''' Helper object for easily printing colored text to the terminal. '''
+    """ Helper object for easily printing colored text to the terminal. """
 
     # Basic console colors
     colors = {
@@ -31,41 +31,41 @@ class Color(object):
 
     @staticmethod
     def p(text):
-        '''
+        """
         Prints text using colored format on same line.
         Example:
             Color.p('{R}This text is red. {W} This text is white')
-        '''
+        """
         sys.stdout.write(Color.s(text))
         sys.stdout.flush()
         if '\r' in text:
-            text = text[text.rfind('\r')+1:]
+            text = text[text.rfind('\r') + 1:]
             Color.last_sameline_length = len(text)
         else:
             Color.last_sameline_length += len(text)
 
     @staticmethod
     def pl(text):
-        '''Prints text using colored format with trailing new line.'''
+        """Prints text using colored format with trailing new line."""
         Color.p('%s\n' % text)
         Color.last_sameline_length = 0
 
     @staticmethod
     def pe(text):
-        '''
+        """
         Prints text using colored format with
         leading and trailing new line to STDERR.
-        '''
+        """
         sys.stderr.write(Color.s('%s\n' % text))
         Color.last_sameline_length = 0
 
     @staticmethod
     def s(text):
-        ''' Returns colored string '''
+        """ Returns colored string """
         output = text
-        for (key, value) in Color.replacements.items():
+        for (key, value) in list(Color.replacements.items()):
             output = output.replace(key, value)
-        for (key, value) in Color.colors.items():
+        for (key, value) in list(Color.colors.items()):
             output = output.replace('{%s}' % key, value)
         return output
 
@@ -84,26 +84,30 @@ class Color(object):
 
     @staticmethod
     def pattack(attack_type, target, attack_name, progress):
-        '''
+        """
         Prints a one-liner for an attack.
         Includes attack type (WEP/WPA),
         target ESSID & power, attack type, and progress.
         ESSID (Pwr) Attack_Type: Progress
         e.g.: Router2G (23db) WEP replay attack: 102 IVs
-        '''
+        """
         essid = '{C}%s{W}' % target.essid if target.essid_known else '{O}unknown{W}'
         Color.p('\r{+} {G}%s{W} ({C}%sdb{W}) {G}%s {C}%s{W}: %s ' % (
             essid, target.power, attack_type, attack_name, progress))
 
     @staticmethod
     def pexception(exception):
-        '''Prints an exception. Includes stack trace if necessary.'''
+        """Prints an exception. Includes stack trace if necessary."""
         Color.pl('\n{!} {R}Error: {O}%s' % str(exception))
 
         # Don't dump trace for the "no targets found" case.
         if 'No targets found' in str(exception):
             return
 
+        # Don't dump trace for the "interface not in monitor mode" case.
+        if 'Enabled interface not in monitor mode' in str(exception):
+            return
+
         from ..config import Configuration
         if Configuration.verbose > 0 or Configuration.print_stack_traces:
             Color.pl('\n{!} {O}Full stack trace below')
@@ -118,6 +122,6 @@ class Color(object):
 
 if __name__ == '__main__':
     Color.pl('{R}Testing{G}One{C}Two{P}Three{W}Done')
-    print(Color.s('{C}Testing{P}String{W}'))
+    print((Color.s('{C}Testing{P}String{W}')))
     Color.pl('{+} Good line')
     Color.pl('{!} Danger')
