@@ -3,8 +3,7 @@
 
 import time
 
-
-class Timer(object):
+class Timer:
     def __init__(self, seconds):
         self.start_time = time.time()
         self.end_time = self.start_time + seconds
@@ -37,4 +36,4 @@ class Timer(object):
         elif mins > 0:
             return '%dm%ds' % (mins, secs)
         else:
-            return '%ds' % secs
+            return '%ds' % secs
\ No newline at end of file
